/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SRC_TRACECONV_TRACE_TO_TEXT_H_
#define SRC_TRACECONV_TRACE_TO_TEXT_H_

#include <iostream>

namespace perfetto {
namespace trace_to_text {

struct TraceToTextOptions {
  // If true, unknown proto fields are skipped when converting to text.
  bool skip_unknown_fields = false;
};

// Returns true in case of success.
bool TraceToText(std::istream* input,
                 std::ostream* output,
                 const TraceToTextOptions& options);

}  // namespace trace_to_text
}  // namespace perfetto

#endif  // SRC_TRACECONV_TRACE_TO_TEXT_H_
